==> haskell-what4-1.6-65-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-K69rcUFpVB1Acmr9i0z9Hk
key:                  what4-1.6-K69rcUFpVB1Acmr9i0z9Hk
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  187c170c0ee519fd02fee64ee9aece64
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-K69rcUFpVB1Acmr9i0z9Hk
depends:
    BoundedChan-1.0.3.0-KC4GwTTdtFBGyIaMAN8c52
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
    bimap-0.5.0-CYX0cWixpvhHpslk6WQrcz
    bv-sized-1.0.6-3jfyfKVjGc0JZuVXsIuZ3Z bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-8hSa9G8vj8g7y3jvxh56oA
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    deepseq-1.4.8.1 deriving-compat-0.6.7-LeMKQoxbUI2JaIdG2X0WhW
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    fingertree-0.1.6.2-9C2f3k75hFcCEg0BQd5B9P ghc-prim-0.10.0
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hashtables-1.4.2-JIYntfUsYaQ63ueo7zjueU
    io-streams-1.5.2.2-6dLtg5IQso2LoK2aAZRuxZ
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    libBF-0.6.6-72Cduw7SzRiAy9JxhoSfMK
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE mtl-2.3.1
    ordered-containers-0.2.4-7LS72pannWi66bkfz7GPiT
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.10.0-K9k2WU6P2flDyJ9do22sx8 parsec-3.1.16.1
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ process-1.6.19.0
    s-cargot-0.1.6.0-FYos3W9HX7aBcMAhfMOA6z
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW stm-2.5.1.0
    template-haskell-2.20.0.0 temporary-1.3-29RL4tTXoFB72QSCtJnhBC
    text-2.0.2 th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    th-lift-instances-0.1.20-LTMKJZnS7WY2o6yRFgu9GC time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    versions-6.0.8-CXPX8fyXIhe6oYqXFQYdjw
    zenc-0.1.2-C9hoLvsJ16eJRsQZ9SMhS1

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-what4-1.6-70-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-FafHRgDtWHhDGrV8cdou6U
key:                  what4-1.6-FafHRgDtWHhDGrV8cdou6U
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  076cc9d37481622e88fc08c40bacaf40
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-FafHRgDtWHhDGrV8cdou6U
depends:
    BoundedChan-1.0.3.0-KC4GwTTdtFBGyIaMAN8c52
    async-2.2.5-BOONqED6PxbDsY8XxcvMc4
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    bifunctors-5.6.2-I7pgRA67vmLKXPFLDlBNmR
    bimap-0.5.0-JHkN8rM6gPHWvGZx2Y9B9
    bv-sized-1.0.6-DGxVu15HfvaDz5EKVBSA8 bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-ENgSRLrrjBs4c4w3nfmgFq
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    deepseq-1.4.8.1 deriving-compat-0.6.7-LcdfKs2wBZ0ARovLl7NdFu
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    fingertree-0.1.6.2-AtFCnpRGf7aEnMC1piO3Sw ghc-prim-0.10.0
    hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL
    hashtables-1.4.2-CndPy8fya8qDgMvOb3mdos
    io-streams-1.5.2.2-GJoryvvGfU1C1jRwIClxDx
    lens-5.3.3-KFcjpRU85K93uhgNXhcmM2
    libBF-0.6.7-Lm4BVkQC33z2ro26FAljIU
    megaparsec-9.7.0-EBrXuyfSuyTIUi7T8Ua8UQ mtl-2.3.1
    ordered-containers-0.2.4-Jg22yiKcxYnJUAMlIUGIoN
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.11.0-BdXPBQmwjWo1EUYdY1GgcP parsec-3.1.16.1
    prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w process-1.6.19.0
    s-cargot-0.1.6.0-E3qu0mCLTcv5aN9HOrgMZC
    scientific-0.3.8.0-E8K90IhCZpR98POp8HwlML stm-2.5.1.0
    template-haskell-2.20.0.0 temporary-1.3-GTgxkhi2PMM37jgbXakJ3s
    text-2.0.2 th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    th-lift-instances-0.1.20-LmKvjtmDbB28aBAJ5h65zr time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-DOqhOSuyr6GEMTQhxoBZ0V
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6
    versions-6.0.8-7ssewknLQ3H5U6a9qBXqk6
    zenc-0.1.2-6cLPiA1qY2JHhTlXH11dVO

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
